@@ -1,6 +1,5 @@
 /*
- Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
- 
+  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -210,7 +209,7 @@ public class JDBC4UpdatableResultSet extends UpdatableResultSet {
 	 */
 	public synchronized void updateNCharacterStream(int columnIndex,
 	        java.io.Reader x, int length) throws SQLException {
-	    String fieldEncoding = this.fields[columnIndex - 1].getCharacterSet();
+	    String fieldEncoding = this.fields[columnIndex - 1].getEncoding();
 	    if (fieldEncoding == null || !fieldEncoding.equals("UTF-8")) {
 	        throw new SQLException(
 	                "Can not call updateNCharacterStream() when field's character set isn't UTF-8");
@@ -261,7 +260,7 @@ public class JDBC4UpdatableResultSet extends UpdatableResultSet {
 	 */
 	public void updateNClob(int columnIndex, java.sql.NClob nClob)
 	        throws SQLException {
-	    String fieldEncoding = this.fields[columnIndex - 1].getCharacterSet();
+	    String fieldEncoding = this.fields[columnIndex - 1].getEncoding();
 	    if (fieldEncoding == null || !fieldEncoding.equals("UTF-8")) {
 	        throw new SQLException("Can not call updateNClob() when field's character set isn't UTF-8");
 	    }
@@ -298,7 +297,7 @@ public class JDBC4UpdatableResultSet extends UpdatableResultSet {
 	 */
 	public synchronized void updateNString(int columnIndex, String x)
 	        throws SQLException {
-	    String fieldEncoding = this.fields[columnIndex - 1].getCharacterSet();
+	    String fieldEncoding = this.fields[columnIndex - 1].getEncoding();
 	    if (fieldEncoding == null || !fieldEncoding.equals("UTF-8")) {
 	        throw new SQLException("Can not call updateNString() when field's character set isn't UTF-8");
 	    }
@@ -318,7 +317,7 @@ public class JDBC4UpdatableResultSet extends UpdatableResultSet {
 	        } else {
 	        	 this.thisRow.setColumnValue(columnIndex - 1, StringUtils.getBytes(x,
 	                        this.charConverter, fieldEncoding,
-	                        this.connection.getServerCharacterEncoding(),
+	                        this.connection.getServerCharset(),
 	                        this.connection.parserKnowsUnicode(), getExceptionInterceptor()));
 	        }
 	    }
@@ -385,7 +384,7 @@ public class JDBC4UpdatableResultSet extends UpdatableResultSet {
 	 *             if an error occurs
 	 */
 	public Reader getNCharacterStream(int columnIndex) throws SQLException {
-		String fieldEncoding = this.fields[columnIndex - 1].getCharacterSet();
+		String fieldEncoding = this.fields[columnIndex - 1].getEncoding();
 		if (fieldEncoding == null || !fieldEncoding.equals("UTF-8")) {
 			throw new SQLException(
 					"Can not call getNCharacterStream() when field's charset isn't UTF-8");
@@ -425,7 +424,7 @@ public class JDBC4UpdatableResultSet extends UpdatableResultSet {
 	 *             if an error occurs
 	 */
 	public NClob getNClob(int columnIndex) throws SQLException {
-		String fieldEncoding = this.fields[columnIndex - 1].getCharacterSet();
+		String fieldEncoding = this.fields[columnIndex - 1].getEncoding();
 		
 		if (fieldEncoding == null || !fieldEncoding.equals("UTF-8")) {
 			throw new SQLException(
@@ -479,7 +478,7 @@ public class JDBC4UpdatableResultSet extends UpdatableResultSet {
 	 *                if a database access error occurs
 	 */
 	public String getNString(int columnIndex) throws SQLException {
-		String fieldEncoding = this.fields[columnIndex - 1].getCharacterSet();
+		String fieldEncoding = this.fields[columnIndex - 1].getEncoding();
 		
 		if (fieldEncoding == null || !fieldEncoding.equals("UTF-8")) {
 			throw new SQLException(
