@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -18,8 +18,9 @@
   You should have received a copy of the GNU General Public License along with this
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
- 
+
  */
+
 package com.mysql.jdbc;
 
 import java.lang.reflect.Constructor;
@@ -324,7 +325,6 @@ public class LoadBalancingConnectionProxy implements InvocationHandler,
 
 		this.exceptionChecker = (LoadBalanceExceptionChecker) Util.loadExtensions(null, props,
 				lbExceptionChecker, "InvalidLoadBalanceExceptionChecker", null).get(0);
-		this.exceptionChecker.init(null, props);
 
 		if(Util.isJdbc4()  || JDBC_4_LB_CONNECTION_CTOR != null){
 			thisAsConnection =  (MySQLConnection) Util.handleNewInstance(JDBC_4_LB_CONNECTION_CTOR,
@@ -616,11 +616,11 @@ public class LoadBalancingConnectionProxy implements InvocationHandler,
 				this.isClosed = false;
 				this.closedReason = null;
 			} else {
-			String reason = "No operations allowed after connection closed.";
-			if(this.closedReason != null){
-				reason += ("  " + this.closedReason);
-			}
-			throw SQLError.createSQLException(
+				String reason = "No operations allowed after connection closed.";
+				if(this.closedReason != null){
+					reason += ("  " + this.closedReason);
+				}
+				throw SQLError.createSQLException(
 					reason,
 					SQLError.SQL_STATE_CONNECTION_NOT_OPEN, null /*
 																 * no access to
@@ -806,7 +806,16 @@ public class LoadBalancingConnectionProxy implements InvocationHandler,
 		Class<?>[] interfaces = clazz.getInterfaces();
 
 		for (int i = 0; i < interfaces.length; i++) {
-			String packageName = interfaces[i].getPackage().getName();
+			String packageName = null;
+			try {
+				packageName = interfaces[i].getPackage().getName();
+			} catch (Exception ex) {
+				// we may experience a NPE from getPackage() returning
+				// null, or class-loading facilities; This happens
+				// when this class is instrumented to implement
+				// runtime-generated interfaces
+				continue;
+			}
 
 			if ("java.sql".equals(packageName)
 					|| "javax.sql".equals(packageName)
@@ -1075,9 +1084,7 @@ public class LoadBalancingConnectionProxy implements InvocationHandler,
 		
 		long[] newResponseTimes = new long[this.responseTimes.length + 1];
 		
-		for (int i = 0; i < this.responseTimes.length; i++) {
-			newResponseTimes[i] = this.responseTimes[i];
-		}
+		System.arraycopy(this.responseTimes, 0, newResponseTimes, 0, this.responseTimes.length);
 		
 		this.responseTimes = newResponseTimes;
 		this.hostList.add(host);
@@ -1140,7 +1147,6 @@ public class LoadBalancingConnectionProxy implements InvocationHandler,
 		target.setCatalog(initial.getCatalog());
 		target.setTransactionIsolation(initial.getTransactionIsolation());
 		target.setReadOnly(initial.isReadOnly());
-
+		target.setSessionMaxRows(initial.getSessionMaxRows());
 	}
-
-}
\ No newline at end of file
+}
