@@ -1,6 +1,6 @@
 /*
-  Copyright (c) 2002, 2013, Oracle and/or its affiliates. All rights reserved.
- 
+  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
+
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
@@ -18,7 +18,9 @@
   You should have received a copy of the GNU General Public License along with this
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
+
  */
+
 package com.mysql.jdbc;
 
 import java.sql.SQLException;
@@ -129,7 +131,7 @@ public class ResultSetMetaData implements java.sql.ResultSetMetaData {
 
 		if (mysqlName != null) {
 			try {
-				javaName = CharsetMapping.MYSQL_TO_JAVA_CHARSET_MAP.get(mysqlName);
+				javaName = CharsetMapping.getJavaEncodingForMysqlCharset(mysqlName);
 			} catch (RuntimeException ex) {
 				SQLException sqlEx = SQLError.createSQLException(ex.toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT, null);
 				sqlEx.initCause(ex);
@@ -152,7 +154,7 @@ public class ResultSetMetaData implements java.sql.ResultSetMetaData {
 	 *             if an invalid column index is given.
 	 */
 	public String getColumnCharacterSet(int column) throws SQLException {
-		return getField(column).getCharacterSet();
+		return getField(column).getEncoding();
 	}
 
 	// --------------------------JDBC 2.0-----------------------------------
