@@ -968,8 +968,15 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		return this.mc.getLog();
 	}
 
+	/**
+	 * @deprecated replaced by <code>getServerCharset()</code>
+	 */
 	public String getServerCharacterEncoding() {
-		return this.mc.getServerCharacterEncoding();
+		return getServerCharset();
+	}
+
+	public String getServerCharset() {
+		return this.mc.getServerCharset();
 	}
 
 	public TimeZone getServerTimezoneTZ() {
@@ -2892,4 +2899,12 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public void setAllowPublicKeyRetrieval(boolean allowPublicKeyRetrieval) throws SQLException {
 		this.mc.setAllowPublicKeyRetrieval(allowPublicKeyRetrieval);
 	}
+
+	public void setDontCheckOnDuplicateKeyUpdateInSQL(boolean dontCheckOnDuplicateKeyUpdateInSQL) {
+		this.mc.setDontCheckOnDuplicateKeyUpdateInSQL(dontCheckOnDuplicateKeyUpdateInSQL);
+	}
+
+	public boolean getDontCheckOnDuplicateKeyUpdateInSQL() {
+		return this.mc.getDontCheckOnDuplicateKeyUpdateInSQL();
+	}
 }
\ No newline at end of file
